import React, { Component, PropTypes } from 'react'
import { VelocityComponent } from 'velocity-react'
import { hamburgerIcon } from './nav-icons'

export default class NavPanelMiddle extends Component {
  constructor (props) {
    super(props)

    this.animation = {
      'closed': {
        display: 'none',
        opacity: 0
      },
      'open': {
        opacity: 1
      }
    }

    this.velocityConfig = {
      duration: 300,
      easing: 'easeOutQuart'
    }

    this.state = {
      isMobile: this.props.isMobile,
      animation: 'closed',
      activeSection: this.props.activeSection
    }
  }

  componentWillReceiveProps (props) {
    this.setState({
      activeSection: props.activeSection,
      isMobile: props.isMobile
    })
  }

  onTabSelect (i, e) {
    e.preventDefault()

    if (this.state.activeSection === i) {
      i = -1
    }

    this.props.setActiveSection(i)
    this.setState({ activeSection: i })
  }

  onToggle (i) {
    this.props.toggle()
    this.setState({
      animation: this.state.animation === 'closed'
        ? 'open'
        : 'closed'
    })
  }

  renderSection (section, i) {
    const onTabSelect = e => !this.hasTouch && this.onTabSelect(i, e)
    let classnames = 'nav-panel-middle__li nav-panel-middle__btn'
    if (this.state.activeSection === i) classnames += ' nav-panel-middle__li--active'
    return (
      <li
        key={ i }
        className={ classnames }>
        <a
          className='font--white'
          href={ section.href }
          onClick={ !section.link && (e => e.preventDefault()) }
          onMouseUp={ !section.link && onTabSelect }
          onTouchEnd={ !section.link && onTabSelect }>
          { section.text }
          { section.extraText ? <span className="extra-text">{ section.extraText }</span> : null }
        </a>
      </li>
    )
  }

  render () {
    return (
      <div className='nav-panel-middle'>
        <ul
          className='nav-panel-middle__ul flex flex--space-between flex--wrap'>
          <a href={ this.props.logoLink } className='flex flex--center-y'>
            <li className='nav-panel-middle__li nav-panel-middle__logo'>
              <img
                className='nav-panel-middle__logo-img'
                src={ this.props.logoUrl } />
            </li>
            <li className='nav-panel-middle__li nav-panel-middle__tagline-container'>
              <p className='nav-panel-middle__tagline'>{ this.props.tagline }</p>
            </li>
          </a>
          <VelocityComponent
            { ...this.velocityConfig }
            animation={ this.state.isMobile
              ? this.animation[this.state.animation]
              : this.animation['open']
            }>
            <div
              className='flex flex--center-all flex--wrap'
              style={{ display: this.state.isMobile ? 'none' : 'inherit' }}>
              { this.props.sections.map(this.renderSection.bind(this)) }
            </div>
          </VelocityComponent>
          <li
            onMouseUp={ !this.hasTouch && this.onToggle.bind(this) }
            onTouchEnd={ this.hasTouch && this.onToggle.bind(this) }
            className='nav-panel-middle__hamburger'>
            <button dangerouslySetInnerHTML={{ __html: hamburgerIcon }} />
          </li>
        </ul>
      </div>
    )
  }
}

const { func, number, bool, string, array } = PropTypes

NavPanelMiddle.propTypes = {
  setActiveSection: func.isRequired,
  toggle: func.isRequired,
  activeSection: number,
  isMobile: bool.isRequired,
  sections: array,
  logoUrl: string,
  logoLink: string,
  tagline: string
}

NavPanelMiddle.defaultProps = {
  logoLink: '/',
  tagline: 'For Giant Ideas',
  activeSection: -1,
}
