import React, { Component, PropTypes } from 'react'
import { VelocityComponent } from 'velocity-react'
import { contactIcon, searchIcon, downloadIcon } from './nav-icons'

// If we're on mongodb.com, links can be root-relative.
// Otherwise they should be absolute.
var dotComOrigin = window.location.host === 'www.mongodb.com' ? '' : 'https://www.mongodb.com'

export default class NavPanelTop extends Component {
  constructor (props) {
    super(props)

    this.velocityConfig = {
      duration: 300,
      easing: 'easeOutQuint'
    }

    this.state = {
      searchOpen: false
    }
  }

  toggleSearch (e) {
    e.preventDefault()
    e.stopPropagation()

    if (!this.state.searchOpen) {
      this.refs.searchInput.focus()
      this.setState({ searchOpen: true })
    } else if (!this.refs.searchInput.value) {
      this.setState({ searchOpen: false })
    } else {
      this.search()
    }
  }

  search () {
    const value = encodeURIComponent(this.refs.searchInput.value)
    window.location.href = `${this.props.searchUrl}${value}`
  }

  render () {
    const { searchOpen } = this.state
    const { includeSearch, contactUrl, sections } = this.props

    return (
      <div className='nav-panel-top font--center'>
        <ul className='flex flex--space-between' style={{ height: '100%' }}>
          <VelocityComponent
            { ...this.velocityConfig }
            animation={ searchOpen
              ? { marginLeft: '-150px', opacity: 0 }
              : { marginLeft: '0', opacity: 1 }
            }
          >
            <div className='flex flex--center-y font--center'>
              { sections.map((section, i) =>
                <a
                  key={ i }
                  className='nav-panel-top__a'
                  target='_blank'
                  href={ section.href }>
                  <li className='nav-panel-top__li'>{ section.text }</li>
                </a>
              ) }
            </div>
          </VelocityComponent>

          <div className='flex flex--center-y'>
            <a href={ contactUrl }>
              <button className='flex flex--center-all flex--wrap nav-panel-top__contact' style={ includeSearch
                ? {}
                : { marginRight: '15px' }
              }>
                { contactIcon }
              </button>
            </a>

            { includeSearch &&
            [<VelocityComponent
              key={ 0 }
              { ...this.velocityConfig }
              animation={ searchOpen
                ? { marginRight: '-35px', opacity: 1 }
                : { marginRight: '-210px', opacity: 0 }
              }
            >
              <input
                className='input nav-panel-top__input'
                onBlur={ () =>
                  window.setTimeout(
                    this.setState.bind(this), 50, { searchOpen: false }
                  )
                }
                onKeyUp={ e => e.keyCode === 13 && this.search() }
                ref='searchInput'
                placeholder='search'
              />
            </VelocityComponent>,
            <VelocityComponent
              key={ 1 }
              { ...this.velocityConfig }
              animation={ searchOpen
                ? { scale: 0.8 }
                : { scale: 1 } }
            >
              <button
                className='flex flex--center-all flex--wrap nav-panel-top__search'
                onMouseDown={ !this.hasTouch && this.toggleSearch.bind(this) }
                onTouchStart={ this.hasTouch && this.toggleSearch.bind(this) }
              >{ searchIcon }</button>
            </VelocityComponent>]
            }

            <a
              className='nav-panel-top__a'
              href={ dotComOrigin + '/download-center?jmp=nav' }
              target={ dotComOrigin ? '_blank' : null }>
              <button className={`
                btn-small btn-fill btn-fill--light-green
                margin--left-xs nav-panel-top__download
              `}>
                <span style={{ verticalAlign: 'middle' }}>Download</span>
                { downloadIcon }
              </button>
            </a>
          </div>
        </ul>
      </div>
    )
  }
}

const { string, bool, array } = PropTypes

NavPanelTop.propTypes = {
  includeSearch: bool,
  searchUrl: string,
  contactUrl: string,
  sections: array
}

NavPanelTop.defaultProps = {
  includeSearch: true,
  searchUrl: '/search?search=',
  contactUrl: '/contact?jmp=nav'
}
